==> baloo-5.84.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5Baloo/KF5BalooConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KF5BalooConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KF5Baloo" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set(BALOO_DBUS_INTERFACES_DIR "${PACKAGE_PREFIX_DIR}/share/dbus-1/interfaces")

include(CMakeFindDependencyMacro)
find_dependency(Qt5Core "5.15.0")
find_dependency(KF5CoreAddons "5.84.0")
find_dependency(KF5FileMetaData "5.84.0")
#find_dependency(LMDB)

include(FeatureSummary)

set_package_properties(LMDB PROPERTIES
    DESCRIPTION "The Lightning Memory-Mapped Databse (LMDB)"
    URL "https://symas.com/lmdb"
)

include("${CMAKE_CURRENT_LIST_DIR}/KF5BalooTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/KF5BalooQchTargets.cmake")

==> baloo-5.85.0-1-aarch64.pkg.tar.xz: usr/lib/cmake/KF5Baloo/KF5BalooConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was KF5BalooConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/KF5Baloo" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set(BALOO_DBUS_INTERFACES_DIR "${PACKAGE_PREFIX_DIR}/share/dbus-1/interfaces")

include(CMakeFindDependencyMacro)
find_dependency(Qt5Core "5.15.0")
find_dependency(KF5CoreAddons "5.85.0")
find_dependency(KF5FileMetaData "5.85.0")
#find_dependency(LMDB)

include(FeatureSummary)

set_package_properties(LMDB PROPERTIES
    DESCRIPTION "The Lightning Memory-Mapped Database (LMDB)"
    URL "https://symas.com/lmdb"
)

include("${CMAKE_CURRENT_LIST_DIR}/KF5BalooTargets.cmake")
include("${CMAKE_CURRENT_LIST_DIR}/KF5BalooQchTargets.cmake")
